@@ -16,7 +16,18 @@
 from collections import OrderedDict
 import os
 import re
-from typing import Dict, Mapping, Optional, Sequence, Tuple, Type, Union
+from typing import (
+    Dict,
+    Mapping,
+    MutableMapping,
+    MutableSequence,
+    Optional,
+    Sequence,
+    Tuple,
+    Type,
+    Union,
+    cast,
+)
 
 from google.api_core import client_options as client_options_lib
 from google.api_core import exceptions as core_exceptions
@@ -27,7 +38,8 @@ from google.auth.exceptions import MutualTLSChannelError  # type: ignore
 from google.auth.transport import mtls  # type: ignore
 from google.auth.transport.grpc import SslCredentials  # type: ignore
 from google.oauth2 import service_account  # type: ignore
-import pkg_resources
+
+from google.cloud.data_fusion_v1 import gapic_version as package_version
 
 try:
     OptionalRetry = Union[retries.Retry, gapic_v1.method._MethodDefault]
@@ -62,7 +74,7 @@ class DataFusionClientMeta(type):
 
     def get_transport_class(
         cls,
-        label: str = None,
+        label: Optional[str] = None,
     ) -> Type[DataFusionTransport]:
         """Returns an appropriate transport class.
 
@@ -364,8 +376,8 @@ class DataFusionClient(metaclass=DataFusionClientMeta):
         self,
         *,
         credentials: Optional[ga_credentials.Credentials] = None,
-        transport: Union[str, DataFusionTransport, None] = None,
-        client_options: Optional[client_options_lib.ClientOptions] = None,
+        transport: Optional[Union[str, DataFusionTransport]] = None,
+        client_options: Optional[Union[client_options_lib.ClientOptions, dict]] = None,
         client_info: gapic_v1.client_info.ClientInfo = DEFAULT_CLIENT_INFO,
     ) -> None:
         """Instantiates the data fusion client.
@@ -379,7 +391,7 @@ class DataFusionClient(metaclass=DataFusionClientMeta):
             transport (Union[str, DataFusionTransport]): The
                 transport to use. If set to None, a transport is chosen
                 automatically.
-            client_options (google.api_core.client_options.ClientOptions): Custom options for the
+            client_options (Optional[Union[google.api_core.client_options.ClientOptions, dict]]): Custom options for the
                 client. It won't take effect if a ``transport`` instance is provided.
                 (1) The ``api_endpoint`` property can be used to override the
                 default endpoint provided by the client. GOOGLE_API_USE_MTLS_ENDPOINT
@@ -409,6 +421,7 @@ class DataFusionClient(metaclass=DataFusionClientMeta):
             client_options = client_options_lib.from_dict(client_options)
         if client_options is None:
             client_options = client_options_lib.ClientOptions()
+        client_options = cast(client_options_lib.ClientOptions, client_options)
 
         api_endpoint, client_cert_source_func = self.get_mtls_endpoint_and_cert_source(
             client_options
@@ -461,11 +474,11 @@ class DataFusionClient(metaclass=DataFusionClientMeta):
 
     def list_available_versions(
         self,
-        request: Union[datafusion.ListAvailableVersionsRequest, dict] = None,
+        request: Optional[Union[datafusion.ListAvailableVersionsRequest, dict]] = None,
         *,
-        parent: str = None,
+        parent: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> pagers.ListAvailableVersionsPager:
         r"""Lists possible versions for Data Fusion instances in
@@ -579,10 +592,10 @@ class DataFusionClient(metaclass=DataFusionClientMeta):
 
     def list_instances(
         self,
-        request: Union[datafusion.ListInstancesRequest, dict] = None,
+        request: Optional[Union[datafusion.ListInstancesRequest, dict]] = None,
         *,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> pagers.ListInstancesPager:
         r"""Lists Data Fusion instances in the specified project
@@ -674,10 +687,10 @@ class DataFusionClient(metaclass=DataFusionClientMeta):
 
     def get_instance(
         self,
-        request: Union[datafusion.GetInstanceRequest, dict] = None,
+        request: Optional[Union[datafusion.GetInstanceRequest, dict]] = None,
         *,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> datafusion.Instance:
         r"""Gets details of a single Data Fusion instance.
@@ -753,13 +766,13 @@ class DataFusionClient(metaclass=DataFusionClientMeta):
 
     def create_instance(
         self,
-        request: Union[datafusion.CreateInstanceRequest, dict] = None,
+        request: Optional[Union[datafusion.CreateInstanceRequest, dict]] = None,
         *,
-        parent: str = None,
-        instance: datafusion.Instance = None,
-        instance_id: str = None,
+        parent: Optional[str] = None,
+        instance: Optional[datafusion.Instance] = None,
+        instance_id: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> operation.Operation:
         r"""Creates a new Data Fusion instance in the specified
@@ -891,11 +904,11 @@ class DataFusionClient(metaclass=DataFusionClientMeta):
 
     def delete_instance(
         self,
-        request: Union[datafusion.DeleteInstanceRequest, dict] = None,
+        request: Optional[Union[datafusion.DeleteInstanceRequest, dict]] = None,
         *,
-        name: str = None,
+        name: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> operation.Operation:
         r"""Deletes a single Date Fusion instance.
@@ -1016,12 +1029,12 @@ class DataFusionClient(metaclass=DataFusionClientMeta):
 
     def update_instance(
         self,
-        request: Union[datafusion.UpdateInstanceRequest, dict] = None,
+        request: Optional[Union[datafusion.UpdateInstanceRequest, dict]] = None,
         *,
-        instance: datafusion.Instance = None,
-        update_mask: field_mask_pb2.FieldMask = None,
+        instance: Optional[datafusion.Instance] = None,
+        update_mask: Optional[field_mask_pb2.FieldMask] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> operation.Operation:
         r"""Updates a single Data Fusion instance.
@@ -1159,10 +1172,10 @@ class DataFusionClient(metaclass=DataFusionClientMeta):
 
     def restart_instance(
         self,
-        request: Union[datafusion.RestartInstanceRequest, dict] = None,
+        request: Optional[Union[datafusion.RestartInstanceRequest, dict]] = None,
         *,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> operation.Operation:
         r"""Restart a single Data Fusion instance.
@@ -1268,14 +1281,9 @@ class DataFusionClient(metaclass=DataFusionClientMeta):
         self.transport.close()
 
 
-try:
-    DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
-        gapic_version=pkg_resources.get_distribution(
-            "google-cloud-data-fusion",
-        ).version,
-    )
-except pkg_resources.DistributionNotFound:
-    DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo()
+DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
+    gapic_version=package_version.__version__
+)
 
 
 __all__ = ("DataFusionClient",)
